Welcome
=======

``carspy`` is a python module for synthesizing and fitting experimental spectra obtained with Coherent Anti-Stokes Raman Spectroscopy (CARS).

.. toctree::
   :maxdepth: 1
   :caption: Get Started

   readme
   installation
   examples
   contributing

.. toctree::
   :maxdepth: 1
   :caption: Modules

   line_strength
   cars_synth
   cars_fit
   convol_fcn
   utils

.. toctree::
   :maxdepth: 1
   :caption: References

   authors
   history
   references
